//   Copyright 2020 Esri
//   Licensed under the Apache License, Version 2.0 (the "License");
//   you may not use this file except in compliance with the License.
//   You may obtain a copy of the License at
//
//   https://www.apache.org/licenses/LICENSE-2.0
//
//   Unless required by applicable law or agreed to in writing, software
//   distributed under the License is distributed on an "AS IS" BASIS,
//   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//   See the License for the specific language governing permissions and
//   limitations under the License.


#include "Display_a_map.h"

#include "ArcGISRuntimeEnvironment.h"
#include "Basemap.h"
#include "Map.h"
#include "MapQuickView.h"
#include <QUrl>

#include "ServiceFeatureTable.h"
#include "FeatureLayer.h"

using namespace Esri::ArcGISRuntime;

Display_a_map::Display_a_map(QObject* parent /* = nullptr */):
  QObject(parent),
  m_map(new Map(BasemapStyle::ArcGISTopographic, this))
{
}

Display_a_map::~Display_a_map()
{
}

MapQuickView* Display_a_map::mapView() const
{
  return m_mapView;
}

void Display_a_map::setupViewpoint()
{
  const Point center(-118.80543, 34.02700, SpatialReference::wgs84());
  const Viewpoint viewpoint(center, 100000.0);
  m_mapView->setViewpoint(viewpoint);

  const QUrl polygonFeatureUrl("https://services3.arcgis.com/GVgbJbqm8hXASVYi/ArcGIS/rest/services/Parks_and_Open_Space/FeatureServer/0");
  ServiceFeatureTable* polygon_feature_table = new ServiceFeatureTable(polygonFeatureUrl, this);

  FeatureLayer* polygon_feature_layer = new FeatureLayer(polygon_feature_table, this);
  m_map->operationalLayers()->append(polygon_feature_layer);

  const QUrl lineFeatureUrl("https://services3.arcgis.com/GVgbJbqm8hXASVYi/ArcGIS/rest/services/Trails/FeatureServer/0");
  ServiceFeatureTable* line_feature_table = new ServiceFeatureTable(lineFeatureUrl, this);

  FeatureLayer* line_feature_layer = new FeatureLayer(line_feature_table, this);
  m_map->operationalLayers()->append(line_feature_layer);

  const QUrl pointFeatureUrl("https://services3.arcgis.com/GVgbJbqm8hXASVYi/arcgis/rest/services/Trailheads/FeatureServer/0");
  ServiceFeatureTable* point_feature_table= new ServiceFeatureTable(pointFeatureUrl, this);

  FeatureLayer* point_feature_layer = new FeatureLayer(point_feature_table, this);
  m_map->operationalLayers()->append(point_feature_layer);

}
// Set the view (created in QML)
void Display_a_map::setMapView(MapQuickView* mapView)
{
  if (!mapView || mapView == m_mapView)
  {
    return;
  }

  m_mapView = mapView;
  m_mapView->setMap(m_map);

  setupViewpoint();

  emit mapViewChanged();
}

