
//   Copyright 2021 Esri
//   Licensed under the Apache License, Version 2.0 (the "License");
//   you may not use this file except in compliance with the License.
//   You may obtain a copy of the License at
//
//   https://www.apache.org/licenses/LICENSE-2.0
//
//   Unless required by applicable law or agreed to in writing, software
//   distributed under the License is distributed on an "AS IS" BASIS,
//   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//   See the License for the specific language governing permissions and
//   limitations under the License.
//

import QtQuick 2.6
import QtQuick.Controls 2.2
import Esri.ArcGISRuntime 100.15

ApplicationWindow {
    id: appWindow
    width: 800
    height: 600
    title: "Display_a_map"

    // add a mapView component
    MapView {
        anchors.fill: parent
        // set focus to enable keyboard navigation
        focus: true

        // add a map to the mapview
        Map {
            // add the ArcGISTopographic basemap to the map
            initBasemapStyle: Enums.BasemapStyleArcGISTopographic
            initialViewpoint: viewpoint

            // Add the polygon feature layer
            FeatureLayer {
                ServiceFeatureTable {
                    url: "https://services3.arcgis.com/GVgbJbqm8hXASVYi/ArcGIS/rest/services/Parks_and_Open_Space/FeatureServer/0"
                }
             }

             // Add the line feature layer
              FeatureLayer {
                ServiceFeatureTable {
                    url: "https://services3.arcgis.com/GVgbJbqm8hXASVYi/ArcGIS/rest/services/Trails/FeatureServer/0"
                }
             }

             // Add the points feature layer
              FeatureLayer {
                ServiceFeatureTable {
                    url: "https://services3.arcgis.com/GVgbJbqm8hXASVYi/arcgis/rest/services/Trailheads/FeatureServer/0"
                }
             }

        }

        ViewpointCenter {
            id: viewpoint
            // Specify the center Point
            center: Point {
                x: -118.80543
                y: 34.02700
                spatialReference: SpatialReference {wkid: 4326}
            }
            // Specify the scale
            targetScale: 100000.0
        }
    }
  }

